#!/bin/bash
# Send SMS message using curl and Vox.io
# 
# 20120528 <nathan@squimp.com>
# 
# Wrote this while waiting for crosstool to finish compiling and
# not wanting to sit around waiting for it when I could be enjoying
# a drink at the corner bar instead. Hence cut+paste the command
# into a shell that is busy compiling, go get a beer, and an SMS
# when the compile has finished. Curl/Vox.io account required


usage() { cat <<EOM

$0 [[-p <password>] -u <usename>] [-n <phone#> -m "<message>"] [-d]

  -p --pass  <password>  (optional)
  -u --user  <username>
      When both provided authenticates and logs in to vox.io.
      When just -u provided, authenticates but prompts user
      for password. If both ommited, assumes login session
      was already built (session cookie stored on disk).

  -n --phone <phone#>
  -m --msg   "<message>"
      When both provided sends message to vox.io and then logs
      the user out and deletes session cookie from disk.

  -d --dryrun
      This option prints the commands executed but does not
      attempt to authenticate or send messages. Useful when 
      wanting to send messages on a machine with curl but
      without this script.

  NOTE: vox.io does not support SSL 

  Examples:
    $0 -p mypassword -u myusername
    # logs user in and stores session
    $0 -n +12035555555 -m "my message"
    # uses previously stored login credentials and sends msg
    $0 -u myusername -n +12035555555 -m "my message"
    # Logs in and sends msg. prompts user for password
    $0 -u myusername -n +12035555555 -m "my message" -d 
    # Adding the -d flag causes the program to print the
    # commands without executing. These can then be pasted
    # into a shell where a process is currently running and
    # when the process is finished they will execute.
    
EOM
}

COOKIEFILE="/tmp/getbeer.cookie"

while true; do
    case "$1" in
        -u | --user) USERNAME=$2; shift 2;;
        -p | --pass) PASSWORD=$2; 
        # check if password is next argument or at end of arg list
        # if so, get password from prompt
        if [[ -z "$PASSWORD" || "${PASSWORD:0:1}" = "-" ]] ; then
            read -s -p "Enter your password: " PASSWORD && echo
            shift 1
        else
            shift 2
        fi
        ;;
        -n | --phone) PHONENUM=$2; shift 2;;
        -m | --msg) MESSAGE=$2; shift 2;;
        -d | --dryrun) dryrun=true; shift 1;;
        *) break;;
    esac
done
if [[ "$USERNAME" ]] ; then
    if [[ -z "$PASSWORD" ]] ; then
        read -s -p "Enter your password: " PASSWORD && echo
    fi
    if [[ -n "$PASSWORD" ]] ; then
        dologin=true
    fi
fi
if [[ "$PHONENUM" && "$MESSAGE" ]] ; then
    dosnd=true
fi

if [ $dologin ] ; then
    CMD="curl --referer http://vox.io/ --cookie-jar $COOKIEFILE --get \
              --data-urlencode \"username=$USERNAME\" --data-urlencode \"password=$PASSWORD\" \
              http://vox.io/auth.localauthentication/authenticate "
    if [ $dryrun ] ; then
        echo $CMD
    else
        echo LOGIN
        eval $CMD && echo
        echo "credentials stored ($COOKIEFILE)"
        chmod 600 $COOKIEFILE
    fi
fi
if [ $dosnd ] ; then
    CMD="curl --referer http://vox.io --cookie $COOKIEFILE --get \
         --data-urlencode \"to=$PHONENUM\" --data-urlencode \"message=$MESSAGE\" \
         http://vox.io/messaging/sendsms "
    if [ $dryrun ] ; then
        echo $CMD
        echo
        echo rm -f $COOKIEFILE
    else
        echo SEND MESSAGE
        eval $CMD && echo
        echo LOGOUT
        curl --referer "http://vox.io" --cookie $COOKIEFILE "http://vox.io/authentication/logout"
        echo "credentials removed (removed $COOKIEFILE)"
        rm -f $COOKIEFILE
    fi
fi
# Not required it seems
#TOKEN="1338166585853"
#--data "_=$TOKEN"

if [[ ! $dologin && ! $dosnd ]] ; then
    usage
    exit 1
fi

exit 0

